@@ -128,17 +128,16 @@ static void         panel_window_set_autohide               (PanelWindow      *w
                                                              gboolean          autohide);
 static void         panel_window_menu_popup                 (PanelWindow      *window,
                                                              guint32           event_time);
-static void         panel_window_update_plugins             (PanelWindow      *window,
+static void         panel_window_plugins_update             (PanelWindow      *window,
                                                              PluginProp        prop);
-static void         panel_window_set_plugin_orientation     (GtkWidget        *widget,
+static void         panel_window_plugin_set_orientation     (GtkWidget        *widget,
                                                              gpointer          user_data);
-static void         panel_window_set_plugin_size            (GtkWidget        *widget,
+static void         panel_window_plugin_set_size            (GtkWidget        *widget,
                                                              gpointer          user_data);
-static void         panel_window_set_plugin_screen_position (GtkWidget        *widget,
+static void         panel_window_plugin_set_screen_position (GtkWidget        *widget,
                                                              gpointer          user_data);
 
 
-
 enum
 {
   PROP_0,
@@ -548,8 +547,8 @@ panel_window_set_property (GObject      *object,
         }
 
       /* send the new orientation and screen position to the panel plugins */
-      panel_window_update_plugins (window, PLUGIN_PROP_ORIENTATION);
-      panel_window_update_plugins (window, PLUGIN_PROP_SCREEN_POSITION);
+      panel_window_plugins_update (window, PLUGIN_PROP_ORIENTATION);
+      panel_window_plugins_update (window, PLUGIN_PROP_SCREEN_POSITION);
       break;
 
     case PROP_SIZE:
@@ -561,7 +560,7 @@ panel_window_set_property (GObject      *object,
         }
 
       /* send the new size to the panel plugins */
-      panel_window_update_plugins (window, PLUGIN_PROP_SIZE);
+      panel_window_plugins_update (window, PLUGIN_PROP_SIZE);
       break;
 
     case PROP_LENGTH:
@@ -635,7 +634,7 @@ panel_window_set_property (GObject      *object,
           panel_window_screen_layout_changed (window->screen, window);
 
           /* send the new screen position to the panel plugins */
-          panel_window_update_plugins (window, PLUGIN_PROP_SCREEN_POSITION);
+          panel_window_plugins_update (window, PLUGIN_PROP_SCREEN_POSITION);
         }
       else
         {
@@ -1007,7 +1006,7 @@ panel_window_button_release_event (GtkWidget      *widget,
       g_object_notify (G_OBJECT (widget), "position");
 
       /* send the new screen position to the panel plugins */
-      panel_window_update_plugins (window, PLUGIN_PROP_SCREEN_POSITION);
+      panel_window_plugins_update (window, PLUGIN_PROP_SCREEN_POSITION);
 
       return TRUE;
     }
@@ -1342,6 +1341,9 @@ panel_window_screen_changed (GtkWidget *widget,
   PanelWindow *window = PANEL_WINDOW (widget);
   GdkScreen   *screen;
 
+  if (G_LIKELY (GTK_WIDGET_CLASS (panel_window_parent_class)->screen_changed != NULL))
+    GTK_WIDGET_CLASS (panel_window_parent_class)->screen_changed (widget, previous_screen);
+
   /* get the new screen */
   screen = gtk_window_get_screen (GTK_WINDOW (widget));
   panel_return_if_fail (GDK_IS_SCREEN (screen));
@@ -1720,9 +1722,21 @@ panel_window_display_layout_debug (GtkWidget *widget)
   for (n = 0; n < n_screens; n++)
     {
       screen = gdk_display_get_screen (display, n);
-      g_string_append_printf (str, "screen-%d[%p]=[%d,%d] (", n, screen,
+      g_string_append_printf (str, "screen-%d[%p]=[%d,%d]", n, screen,
           gdk_screen_get_width (screen), gdk_screen_get_height (screen));
 
+      if (panel_debug_has_domain (PANEL_DEBUG_DISPLAY_LAYOUT))
+        {
+          g_string_append_printf (str, "{comp=%s, sys=%p:%p, rgba=%p:%p}",
+              PANEL_DEBUG_BOOL (gdk_screen_is_composited (screen)),
+              gdk_screen_get_system_colormap (screen),
+              gdk_screen_get_system_visual (screen),
+              gdk_screen_get_rgba_colormap (screen),
+              gdk_screen_get_rgba_visual (screen));
+        }
+
+      str = g_string_append (str, " (");
+
       n_monitors = gdk_screen_get_n_monitors (screen);
       for (m = 0; m < n_monitors; m++)
         {
@@ -1746,8 +1760,10 @@ panel_window_display_layout_debug (GtkWidget *widget)
     }
 
   panel_debug (PANEL_DEBUG_DISPLAY_LAYOUT,
-               "%p: display=%s, %s", widget,
-               gdk_display_get_name (display), str->str);
+               "%p: display=%s{comp=%s}, %s", widget,
+               gdk_display_get_name (display),
+               PANEL_DEBUG_BOOL (gdk_display_supports_composite (display)),
+               str->str);
 
   g_string_free (str, TRUE);
 }
@@ -2318,7 +2334,7 @@ panel_window_menu_popup (PanelWindow *window,
 
 
 static void
-panel_window_update_plugins (PanelWindow *window,
+panel_window_plugins_update (PanelWindow *window,
                              PluginProp   prop)
 {
   GtkWidget   *itembar;
@@ -2329,15 +2345,16 @@ panel_window_update_plugins (PanelWindow *window,
   switch (prop)
     {
     case PLUGIN_PROP_ORIENTATION:
-      func = panel_window_set_plugin_orientation;
+      func = panel_window_plugin_set_orientation;
       break;
 
     case PLUGIN_PROP_SCREEN_POSITION:
-      func = panel_window_set_plugin_screen_position;
+      func = panel_window_plugin_set_screen_position;
       break;
 
     case PLUGIN_PROP_SIZE:
-      func = panel_window_set_plugin_size;
+      func = panel_window_plugin_set_size;
+      break;
       break;
 
     default:
@@ -2356,7 +2373,7 @@ panel_window_update_plugins (PanelWindow *window,
 
 
 static void
-panel_window_set_plugin_orientation (GtkWidget *widget,
+panel_window_plugin_set_orientation (GtkWidget *widget,
                                      gpointer   user_data)
 {
   panel_return_if_fail (XFCE_IS_PANEL_PLUGIN_PROVIDER (widget));
@@ -2370,7 +2387,7 @@ panel_window_set_plugin_orientation (GtkWidget *widget,
 
 
 static void
-panel_window_set_plugin_size (GtkWidget *widget,
+panel_window_plugin_set_size (GtkWidget *widget,
                               gpointer   user_data)
 {
   panel_return_if_fail (XFCE_IS_PANEL_PLUGIN_PROVIDER (widget));
@@ -2383,7 +2400,7 @@ panel_window_set_plugin_size (GtkWidget *widget,
 
 
 static void
-panel_window_set_plugin_screen_position (GtkWidget *widget,
+panel_window_plugin_set_screen_position (GtkWidget *widget,
                                          gpointer   user_data)
 {
   PanelWindow        *window = PANEL_WINDOW (user_data);
@@ -2467,6 +2484,7 @@ panel_window_new (GdkScreen *screen)
                        "screen", screen,
                        "type-hint", GDK_WINDOW_TYPE_HINT_DOCK,
                        "gravity", GDK_GRAVITY_STATIC,
+                       "role", "Panel",
                        "name", "XfcePanelWindow",
                        NULL);
 }
@@ -2511,9 +2529,9 @@ panel_window_set_povider_info (PanelWindow *window,
         }
     }
 
-  panel_window_set_plugin_orientation (provider, window);
-  panel_window_set_plugin_screen_position (provider, window);
-  panel_window_set_plugin_size (provider, window);
+  panel_window_plugin_set_orientation (provider, window);
+  panel_window_plugin_set_screen_position (provider, window);
+  panel_window_plugin_set_size (provider, window);
 }
 
 
