@@ -11,9 +11,9 @@
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  * more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -390,8 +390,8 @@ pager_buttons_rebuild_idle (gpointer user_data)
           gtk_container_add (GTK_CONTAINER (button), label);
           gtk_widget_show (label);
 
-          row = n / rows;
-          col = n % rows;
+          row = n % cols;
+          col = n / cols;
 
           gtk_table_attach (GTK_TABLE (pager), button,
                             row, row + 1, col, col + 1,
@@ -426,8 +426,8 @@ pager_buttons_rebuild_idle (gpointer user_data)
 
           pager->buttons = g_slist_prepend (pager->buttons, button);
 
-          row = n / rows;
-          col = n % rows;
+          row = n % cols;
+          col = n / cols;
 
           gtk_table_attach (GTK_TABLE (pager), button,
                             row, row + 1, col, col + 1,
